aboutsummaryrefslogtreecommitdiff
path: root/lib/VNLib.Plugins.Extensions.Loading/src/ConfigurationExtensions.cs
diff options
context:
space:
mode:
authorLibravatar vnugent <public@vaughnnugent.com>2023-04-08 16:43:52 -0400
committerLibravatar vnugent <public@vaughnnugent.com>2023-04-08 16:43:52 -0400
commite77477b81e5623502b19db0fb29d4ea88c26b934 (patch)
treee91be0069d011c86ea138a8561c12b5df9b0005c /lib/VNLib.Plugins.Extensions.Loading/src/ConfigurationExtensions.cs
parent208ae0f26408abe7f63a95bc28cb8e0bdb673efa (diff)
Passwords singlton and user-loading
Diffstat (limited to 'lib/VNLib.Plugins.Extensions.Loading/src/ConfigurationExtensions.cs')
-rw-r--r--lib/VNLib.Plugins.Extensions.Loading/src/ConfigurationExtensions.cs18
1 files changed, 9 insertions, 9 deletions
diff --git a/lib/VNLib.Plugins.Extensions.Loading/src/ConfigurationExtensions.cs b/lib/VNLib.Plugins.Extensions.Loading/src/ConfigurationExtensions.cs
index 0ae6ed6..190c153 100644
--- a/lib/VNLib.Plugins.Extensions.Loading/src/ConfigurationExtensions.cs
+++ b/lib/VNLib.Plugins.Extensions.Loading/src/ConfigurationExtensions.cs
@@ -221,12 +221,12 @@ namespace VNLib.Plugins.Extensions.Loading
/// <summary>
/// Deserialzes the configuration to the desired object and calls its
/// <see cref="IOnConfigValidation.Validate"/> method. Validation exceptions
/// are wrapped in a <see cref="ConfigrationValidationException"/>
/// </summary>
/// <typeparam name="T"></typeparam>
/// <param name="scope"></param>
/// <returns></returns>
- /// <exception cref="ConfigrationValidationException"></exception>
+ /// <exception cref="ConfigurationValidationException"></exception>
public static T DeserialzeAndValidate<T>(this IConfigScope scope) where T : IOnConfigValidation
{
T conf = scope.Deserialze<T>();
@@ -236,7 +236,7 @@ namespace VNLib.Plugins.Extensions.Loading
}
catch(Exception ex)
{
- throw new ConfigrationValidationException($"Configuration validation failed for type {typeof(T).Name}", ex);
+ throw new ConfigurationValidationException($"Configuration validation failed for type {typeof(T).Name}", ex);
}
return conf;
}
@@ -261,7 +261,7 @@ namespace VNLib.Plugins.Extensions.Loading
/// and deserializes it into the desired type.
/// <para>
/// If the type inherits <see cref="IOnConfigValidation"/> the <see cref="IOnConfigValidation.Validate"/>
/// method is invoked, and exceptions are warpped in <see cref="ConfigrationValidationException"/>
/// </para>
/// <para>
/// If the type inherits <see cref="IAsyncConfigurable"/> the <see cref="IAsyncConfigurable.ConfigureServiceAsync(PluginBase)"/>
@@ -271,7 +271,7 @@ namespace VNLib.Plugins.Extensions.Loading
/// <typeparam name="TConfig">The configuration type</typeparam>
/// <param name="plugin"></param>
/// <returns>The deserialzed configuration element</returns>
- /// <exception cref="ConfigrationValidationException"></exception>
+ /// <exception cref="ConfigurationValidationException"></exception>
public static TConfig GetConfigElement<TConfig>(this PluginBase plugin)
{
//Deserialze the element
@@ -286,7 +286,7 @@ namespace VNLib.Plugins.Extensions.Loading
}
catch (Exception ex)
{
- throw new ConfigrationValidationException($"Configuration validation failed for type {typeof(TConfig).Name}", ex);
+ throw new ConfigurationValidationException($"Configuration validation failed for type {typeof(TConfig).Name}", ex);
}
}
@@ -304,7 +304,7 @@ namespace VNLib.Plugins.Extensions.Loading
/// and deserializes it into the desired type.
/// <para>
/// If the type inherits <see cref="IOnConfigValidation"/> the <see cref="IOnConfigValidation.Validate"/>
/// method is invoked, and exceptions are warpped in <see cref="ConfigrationValidationException"/>
/// </para>
/// <para>
/// If the type inherits <see cref="IAsyncConfigurable"/> the <see cref="IAsyncConfigurable.ConfigureServiceAsync(PluginBase)"/>
@@ -315,7 +315,7 @@ namespace VNLib.Plugins.Extensions.Loading
/// <param name="plugin"></param>
/// <param name="elementName">The configuration element name override</param>
/// <returns>The deserialzed configuration element</returns>
- /// <exception cref="ConfigrationValidationException"></exception>
+ /// <exception cref="ConfigurationValidationException"></exception>
public static TConfig GetConfigElement<TConfig>(this PluginBase plugin, string elementName)
{
//Deserialze the element
@@ -330,7 +330,7 @@ namespace VNLib.Plugins.Extensions.Loading
}
catch (Exception ex)
{
- throw new ConfigrationValidationException($"Configuration validation failed for type {typeof(TConfig).Name}", ex);
+ throw new ConfigurationValidationException($"Configuration validation failed for type {typeof(TConfig).Name}", ex);
}
}
@@ -221,12 +221,12 @@ namespace VNLib.Plugins.Extensions.Loading
/// Deserialzes the configuration to the desired object and calls its
/// <see cref="IOnConfigValidation.Validate"/> method. Validation exceptions
- /// are wrapped in a <see cref="ConfigrationValidationException"/>
+ /// are wrapped in a <see cref="ConfigurationValidationException"/>
/// </summary>
/// <typeparam name="T"></typeparam>
@@ -261,7 +261,7 @@ namespace VNLib.Plugins.Extensions.Loading
/// <para>
/// If the type inherits <see cref="IOnConfigValidation"/> the <see cref="IOnConfigValidation.Validate"/>
- /// method is invoked, and exceptions are warpped in <see cref="ConfigrationValidationException"/>
+ /// method is invoked, and exceptions are warpped in <see cref="ConfigurationValidationException"/>
/// </para>
/// <para>
@@ -304,7 +304,7 @@ namespace VNLib.Plugins.Extensions.Loading
/// <para>
/// If the type inherits <see cref="IOnConfigValidation"/> the <see cref="IOnConfigValidation.Validate"/>
- /// method is invoked, and exceptions are warpped in <see cref="ConfigrationValidationException"/>
+ /// method is invoked, and exceptions are warpped in <see cref="ConfigurationValidationException"/>
/// </para>
/// <para>